from distutils.core import setup

setup(
    name='fwl-ddd-seedwork',  # How you named your package folder (MyLib)
    version='0.1',
    license='MIT',
    description='simple ddd seedwork',
    author='Alexandre Herculano',
    author_email='aherculano0109@gmail.com',
    url='https://github.com/aherculano/fwl-ddd-seedwork',
    python_requires='>=3.6'
)
